@@ -3,16 +3,17 @@
 """ Configuration for the eGenix mx Base Distribution
 
     Copyright (c) 1997-2000, Marc-Andre Lemburg; mailto:mal@lemburg.com
-    Copyright (c) 2000-2008, eGenix.com Software GmbH; mailto:info@egenix.com
+    Copyright (c) 2000-2009, eGenix.com Software GmbH; mailto:info@egenix.com
     See the documentation for further information on copyrights,
     or contact the author. All Rights Reserved.
 """
+import sys
 from mxSetup import mx_Extension, mx_version
 
 #
 # Package version
 #
-version = mx_version(3, 1, 1)
+version = mx_version(3, 1, 2)
 
 #
 # Setup information
@@ -31,15 +32,55 @@ additions to everyday Python programming.
 The Base Distribution includes the Open Source subpackages of the
 series and is needed by all other add-on packages of the series:
 
- * mxDateTime - Date/Time Library for Python
- * mxTextTools - Fast Text Parsing and Processing Tools for Python
- * mxProxy - Object Access Control for Python
- * mxBeeBase - On-disk B+Tree Based Database Kit for Python
- * mxURL - Flexible URL Data-Type for Python
- * mxUID - Fast Universal Identifiers for Python
- * mxStack - Fast and Memory-Efficient Stack Type for Python
- * mxQueue - Fast and Memory-Efficient Queue Type for Python
- * mxTools - Fast Everyday Helpers for Python
+mxDateTime - Date/Time Library for Python
+
+    mxDateTime implements three new object types, DateTime,
+    DateTimeDelta and RelativeDateTime and many tools based on these
+    for doing easy conversion between and parsing of various date/time
+    formats.
+
+mxTextTools - Fast Text Parsing and Processing Tools for Python
+
+    mxTextTools provides several useful functions and types that
+    implement high-performance text parsing, processing and search
+    algorithms.
+
+mxProxy - Object Access Control for Python
+
+    mxProxy implements a new proxy type to provide low-level object
+    access control, weak referencing and a cleanup protocol. It's
+    ideal for use in restricted execution environments.
+
+mxBeeBase - On-disk B+Tree Based Database Kit for Python
+
+    mxBeeBase is a high performance construction kit for disk based
+    indexed databases. It offers components which you can plug
+    together to easily build your own custom mid-sized databases.
+
+mxURL - Flexible URL Data-Type for Python
+
+    mxURL provides a new datatype for storing and manipulating URL
+    values as well as a few helpers related to URL building, encoding
+    and decoding.
+
+mxUID - Fast Universal Identifiers for Python
+
+    mxUID implements a fast mechanism for generating universal
+    identification strings (UIDs).
+
+mxStack - Fast and Memory-Efficient Stack Type for Python
+
+    mxStack implements a fast and memory efficient stack object type.
+
+mxQueue - Fast and Memory-Efficient Queue Type for Python
+
+    mxQueue implements a fast and memory efficient queue object type.
+
+mxTools - Fast Everyday Helpers for Python
+
+    mxTools provides a collection of handy functions and objects for
+    every day Python programming. It includes many functions that
+    you've often missed in Python.
 
 This software is brought to you by eGenix.com and distributed under
 the eGenix.com Public License 1.1.0.
@@ -47,7 +88,7 @@ the eGenix.com Public License 1.1.0.
 license = (
 "eGenix.com Public License 1.1.0; "
 "Copyright (c) 1997-2000, Marc-Andre Lemburg, All Rights Reserved; "
-"Copyright (c) 2000-2008, eGenix.com Software GmbH, All Rights Reserved"
+"Copyright (c) 2000-2009, eGenix.com Software GmbH, All Rights Reserved"
 )
 author = "Marc-Andre Lemburg"
 author_email = "mal@egenix.com"
@@ -81,6 +122,11 @@ classifiers = [
     "Operating System :: Other OS",
     "Programming Language :: C",
     "Programming Language :: Python",
+    "Programming Language :: Python :: 2",
+    "Programming Language :: Python :: 2.3",
+    "Programming Language :: Python :: 2.4",
+    "Programming Language :: Python :: 2.5",
+    "Programming Language :: Python :: 2.6",
     "Topic :: Communications",
     "Topic :: Database",
     "Topic :: Documentation",
@@ -165,6 +211,28 @@ packages = [
 #
 # C Extensions
 #
+
+# Determine optional platform-dependent features
+if sys.platform[:3] != 'win':
+    # Unix-like platforms
+    _mxDateTime_optional_libraries = [
+        # mxDateTime needs floor() and ceil() which are sometimes
+        # defined in libm. Python normally already references this
+        # library if necessary, so not finding the library is not
+        # necessarily a reason to fail building mxDateTime.
+        ('m', ['math.h']),
+        ]
+    _mxTools_optional_libraries = [
+        # The optional mx.Tools.dlopen() function needs the dl lib in
+        # order to load dynamic libaries on Unix platforms.
+        ('dl', ['dlfcn.h']),
+        ]
+else:
+    # On Windows, the extra libs are not needed (or even available)
+    _mxDateTime_optional_libraries = []
+    _mxTools_optional_libraries = []
+    
+# Extension definitions
 ext_modules = [
 
     # mxDateTime
@@ -173,7 +241,8 @@ ext_modules = [
                  # If mxDateTime doesn't compile, try removing the next line.
                  define_macros=[('USE_FAST_GETCURRENTTIME', None)],
                  #
-                 include_dirs=['mx/DateTime/mxDateTime']
+                 include_dirs=['mx/DateTime/mxDateTime'],
+                 optional_libraries=_mxDateTime_optional_libraries,
                  ),
 
     # mxProxy
@@ -203,12 +272,20 @@ ext_modules = [
     mx_Extension('mx.Tools.mxTools.mxTools',
                  ['mx/Tools/mxTools/mxTools.c'],
                  define_macros=[
-                 # To enable mx.Tools.setproctitle(), you have to enable
-                 # the following line. Note that not all Python versions
-                 # expose the required Py_GetArgcArgv() API.
-                 #               ('HAVE_PY_GETARGCARGV', None)],
+
+                     # To enable mx.Tools.setproctitle(), you have to enable
+                     # the following line. Note that not all Python versions
+                     # expose the required Py_GetArgcArgv() API.
+                     # ('HAVE_PY_GETARGCARGV', None),
+                     
+                     # If you want to use the experimental mx.Tools.safecall()
+                     # API, you have to enable the following line.
+                     # ('MXTOOLS_ENABLE_SAFECALL', None),
+                     
                  ],
-                 include_dirs=['mx/Tools/mxTools']),
+                 include_dirs=['mx/Tools/mxTools'],
+                 optional_libraries=_mxTools_optional_libraries,
+                 ),
 
     # xmap is no longer supported
     #mx_Extension('mx.Tools.mxTools.xmap',
